nodes['home.nas'] = {
    'hostname': '172.19.138.20',
    'bundles': {
        'avahi-daemon',
        'backup-client',
        'jellyfin',
        'lm-sensors',
        'mixcloud-downloader',
        'mosquitto',
        'navidrome',
        'nfs-server',
        'rsyslogd',
        'samba',
        'smartd',
        'snapserver',
        'vmhost',
        'zfs',
    },
    'groups': {
        'debian-bookworm',
        'webserver',
    },
    'metadata': {
        'interfaces': {
            'br1138': {
                'ips': {
                    '172.19.138.20/24',
                },
                'gateway4': '172.19.138.1',
                'ipv6_accept_ra': True,
            },
        },
        'apt': {
            'unattended-upgrades': {
                'day': 6,
                # requires manual decryption of zfs after reboot
                'reboot_enabled': False,
            },
            'packages': {
                'mpv': {},

                # for hardware transcoding of video
                'firmware-amd-graphics': {},
                'mesa-va-drivers': {},

                # for compiling yate
                'autoconf': {},
                'subversion': {},
                # svn checkout http://yate.null.ro/svn/yate/tags/RELEASE_6_4_0/ .
                # ./autogen.sh
                # ./configure --prefix=/opt/yate
                # make -j8
                # systemctl stop yate
                # make install-noconf
                # systemctl start yate
            },
        },
        'avahi-daemon': {
            'use-ipv6': False, # because having a dynamic address confuses the network somehow
        },
        'backups': {
            'paths': {
                '/home/kunsi/',
                '/opt/yate/',
                '/storage/nas/',
            },
        },
        'cron': {
            'jobs': {
                'avahi-aruba-fixup': '17,47 * * * *   root    /usr/bin/systemctl restart avahi-daemon.service',
            },
        },
        'groups': {
            'nas': {},
        },
        'firewall': {
            'port_rules': {
                '5060/tcp': { # yate SIP
                    'home.snom-wohnzimmer',
                },
                '5061/tcp': { # yate SIPS
                    'home.snom-wohnzimmer',
                },
                # yate RTP uses some random UDP port. We cannot firewall
                # it, because for incoming calls the other side decides
                # which port to use. That's why we simply allow all UDP
                # traffic from our SIP clients. It's fine to do so, because
                # all sip clients are known to bundlewrap, so we won't have
                # to deal with randomly changing IPs here.
                '*/udp': {
                    'home.snom-wohnzimmer',
                },
            },
        },
        'mixcloud-downloader': {
            'netrc': {
                'soundcloud': {
                    'username': 'oauth',
                    'password': bwpass.attr('soundcloud.com/hi@kunsmann.eu', 'oauth_token'),
                },
            },
        },
        'mosquitto': {
            'bridges': {
                'c3voc': {
                    'peer': 'mqtt.c3voc.de',
                    'client_id': 'kunsi-home',
                    'auth': {
                        'username': vault.decrypt('encrypt$gAAAAABgaBa5UZyZlsMM9TV5pa-VyOieFWYzAslxWVnXjOeXHvF4kMHHSHSMOrv-U9k7Ec3mMCDuJFO3ybpOsZSeFQDL7GgEfw=='),
                        'password': vault.decrypt('encrypt$gAAAAABgaBbfm65cYBuod0UehWNmY0NfeUH9xsrP2kENYNF_LWP2iV5a8db_cqMoITwyjjBsHpvjaeDq07Z5K5nQ_BLZG6zPqapL-Qvp20wyck49Dy2R4V4='),
                    },
                    'topics': [
                        {
                            'pattern': '#',
                            'remote_prefix': '/voc/',
                            'local_prefix': 'voc'
                        },
                    ],
                },
            },
            'listeners': {
                '8083': {
                    'protocol': 'websockets',
                },
            },
            'tasmota-telegraf-topic': '/switch/#',
            'restrict-to': {
                '172.19.136.0/25',
                '172.19.138.0/24',
                'htz-cloud.molly-connector',
            },
        },
        'navidrome': {
            'domain': 'navidrome.lulu26.eu',
            'version': '0.57.0',
            'sha1': 'db590c5007a205ff58b1f679bb38ccd74e141417',
            'zfs_base': 'ssdpool',
            'config': {
                'EnableExternalServices': True, # need spotify for artist images
                'EnableSharing': True,
                'EnableStarRating': False,
                'IgnoredArticles': 'The El La Los Las Le Les Os As O A Der Die Das',
                'MusicFolder': '/storage/nas/music',
                'PasswordEncryptionKey': vault.decrypt('encrypt$gAAAAABoRXLELiE8_PQyh4elPnSgMDKi7mPpNZweAZQykvfUbeVHv2JVXyzbOOerL3STeTIv8QbGKAqVGyDSzACRdGg4S6DP6Q5FiKFFbkOgKgc7WXQfT59QRP8jMoc2QSe_SQ3SvHFv'),
                # currently broken <https://github.com/navidrome/navidrome/issues/4026>
                #'Spotify': {
                #    'ID': vault.decrypt('encrypt$gAAAAABoRXGJc4qqAttRNsRIP6N9yJ5LPMwItFW4vwm6Dnf9LVgaYdsXD1D-yx32B5iHgLIDCoeds2IpCAZCtPpmN-75i9AeblQGmqEopUThdkpOxeCwwJtBFkhl36T_O5YjLRA5MAYo'),
                #    'Secret': vault.decrypt('encrypt$gAAAAABoRXGOyOItedfJI10IkAlfHYeiJUcCzYqCLQMkMecK8X3d_tsssCeE5lWZshEvgWVqWW7Iyi-as22uI6PEa0Xm3uwJUNvvRR2qCnwpX0Adv-4NZ7WizA6KX6E6P2zIYZ6tneeG'),
                #},
            },
        },
        'nfs-server': {
            'shares': {
                '/mnt/download': {
                    'home.downloadhelper': 'rw,all_squash,anonuid=65534,anongid=1012,no_subtree_check',
                },
                '/storage/nas': {
                    '172.19.138.0/24': 'ro,all_squash,anonuid=65534,anongid=65534,no_subtree_check,insecure',
                },
                '/srv/paperless': {
                    'home.paperless': 'rw,all_squash,anonuid=65534,anongid=65534,no_subtree_check',
                },
            },
        },
        'nginx': {
            'vhosts': {
                'jellyfin': {
                    'create_logs': True,
                    'domain': 'jellyfin.lulu26.eu',
                    'ssl': '_.lulu26.eu',
                },
                'navidrome': {
                    'ssl': '_.lulu26.eu',
                },
                'snapserver': {
                    'ssl': '_.lulu26.eu',
                },
            },
        },
        'rsyslogd': {
            'restrict-to': {
                'home',
            },
        },
        'samba': {
            'restrict-to': {
                '172.19.138.0/24',
            },
            'timemachine-shares': {
                'apfelcomputer',
                'verrat',
            },
        },
        'smartd': {
            'disks': {
                '/dev/nvme0',

                # nas/timemachine disks
                '/dev/disk/by-id/ata-WDC_WD6003FFBX-68MU3N0_V8GE15GR',
                '/dev/disk/by-id/ata-WDC_WD6003FFBX-68MU3N0_V8HJ406R',
                '/dev/disk/by-id/ata-WDC_WD6003FFBX-68MU3N0_V8HJBTLR',
                '/dev/disk/by-id/ata-WDC_WD6003FFBX-68MU3N0_V8HJGN6R',
                '/dev/disk/by-id/ata-WDC_WD6003FFBX-68MU3N0_V8J8ZKRR',
                '/dev/disk/by-id/ata-WDC_WD6003FFBX-68MU3N0_V9JS5UYL',

                # ssdpool disks
                '/dev/disk/by-id/ata-INTEL_SSDSC2KB960G8_PHYF244001QU960CGN',
                '/dev/disk/by-id/ata-INTEL_SSDSC2KB960G8_PHYF244002AS960CGN',
            },
        },
        'snapserver': {
            'domain': 'snapserver.lulu26.eu',
            'restrict-to': {
                '172.19.138.0/24',
            },
        },
        'systemd-networkd': {
            'bridges': {
                'br0': {
                    'match': {
                        'eno1',
                    },
                },
                'br1138': {
                    'match': {
                        'br0.1138',
                    },
                },
                'br1139': {
                    'match': {
                        'br0.1139',
                    },
                },
            },
        },
        'systemd-timers': {
            'timers': {
                # Ensure every user is able to read and write to the NAS dataset.
                'nas_permissions': {
                    'command': [
                        'chown -R :nas /storage/nas/',
                        r'find /storage/nas/ -type d -exec chmod 0775 {} \;',
                        r'find /storage/nas/ -type f -exec chmod 0664 {} \;',
                        'find /storage/nas/ -type f -name "._*" -delete',
                    ],
                    'when': '*-*-* 02:00:00',
                },
            },
        },
        'openssh': {
            'enable_x_forwarding_for_admins': True,
        },
        'users': {
            #'inbox': {
            #    'ssh_pubkey': {
            #        #'command="/usr/share/rsync/scripts/rrsync -wo /storage/inbox/",no-agent-forwarding,no-port-forwarding,no-pty,no-user-rc,no-X11-forwarding ',
            #    },
            #},
            'kunsi': {
                'groups': {
                    'nas',
                },
            },
        },
        'zfs': {
            'module_options': {
                'zfs_arc_max_gb': 8,
            },
            'pools': {
                'ssdpool': {
                    'when_creating': {
                        'config': [
                            {
                                'type': 'mirror',
                                'devices': {
                                    '/dev/disk/by-id/ata-INTEL_SSDSC2KB960G8_PHYF244001QU960CGN',
                                    '/dev/disk/by-id/ata-INTEL_SSDSC2KB960G8_PHYF244002AS960CGN',
                                },
                            },
                        ],
                        'ashift': 12,
                    },
                },
                'tank': {
                    'when_creating': {
                        'config': [
                            {
                                'type': 'raidz2',
                                'devices': {
                                    '/dev/disk/by-id/ata-WDC_WD6003FFBX-68MU3N0_V8GE15GR',
                                    '/dev/disk/by-id/ata-WDC_WD6003FFBX-68MU3N0_V8HJ406R',
                                    '/dev/disk/by-id/ata-WDC_WD6003FFBX-68MU3N0_V8HJBTLR',
                                    '/dev/disk/by-id/ata-WDC_WD6003FFBX-68MU3N0_V8HJGN6R',
                                    '/dev/disk/by-id/ata-WDC_WD6003FFBX-68MU3N0_V9JS5UYL',
                                    '/dev/disk/by-id/ata-WDC_WD6003FFBX-68MU3N0_V8J8ZKRR',
                                },
                            },
                        ],
                        'ashift': 12,
                    },
                },
            },
            'datasets': {
                'ssdpool': {
                    'primarycache': 'metadata',
                },
                'ssdpool/yate': {
                    'mountpoint': '/opt/yate',
                },
                'ssdpool/download': {
                    'mountpoint': '/mnt/download',
                    'quota': '858993459200', # 800 GB
                },
                'ssdpool/paperless': {
                    'mountpoint': '/srv/paperless',
                },
                'tank': {
                    'primarycache': 'metadata',
                },
                'tank/nas': {
                    'acltype': 'off',
                    'atime': 'off',
                    'compression': 'off',
                    'mountpoint': '/storage/nas',
                },
            },
            'snapshots': {
                'retain_per_dataset': {
                    'tank/nas': {
                        # juuuuuuuust to be sure.
                        'daily': 14,
                        'weekly': 6,
                        'monthly': 12,
                    },
                    'ssdpool/download': {
                        'hourly': 48,
                        'daily': 0,
                        'weekly': 0,
                        'monthly': 0,
                    },
                    'ssdpool/paperless': {
                        'daily': 14,
                        'weekly': 6,
                        'monthly': 24,
                    },
                },
            },
        },
        'vm': {
            'cpu': 8,
            'ram': 32,
        },
    },
}
